@@ -1217,6 +1217,64 @@ def test_bigquery_magic_w_maximum_bytes_billed_w_context_setter():
     assert sent_config["maximumBytesBilled"] == "10203"
 
 
+@pytest.mark.usefixtures("ipython_interactive")
+@pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
+def test_bigquery_magic_with_no_query_cache(monkeypatch):
+    ip = IPython.get_ipython()
+    ip.extension_manager.load_extension("google.cloud.bigquery")
+    conn = make_connection()
+    monkeypatch.setattr(magics.context, "_connection", conn)
+    monkeypatch.setattr(magics.context, "project", "project-from-context")
+
+    # --no_query_cache option should override context.
+    monkeypatch.setattr(
+        magics.context.default_query_job_config, "use_query_cache", True
+    )
+
+    ip.run_cell_magic("bigquery", "--no_query_cache", QUERY_STRING)
+
+    conn.api_request.assert_called_with(
+        method="POST",
+        path="/projects/project-from-context/jobs",
+        data=mock.ANY,
+        timeout=DEFAULT_TIMEOUT,
+    )
+    jobs_insert_call = [
+        call
+        for call in conn.api_request.call_args_list
+        if call[1]["path"] == "/projects/project-from-context/jobs"
+    ][0]
+    assert not jobs_insert_call[1]["data"]["configuration"]["query"]["useQueryCache"]
+
+
+@pytest.mark.usefixtures("ipython_interactive")
+@pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
+def test_context_with_no_query_cache_from_context(monkeypatch):
+    ip = IPython.get_ipython()
+    ip.extension_manager.load_extension("google.cloud.bigquery")
+    conn = make_connection()
+    monkeypatch.setattr(magics.context, "_connection", conn)
+    monkeypatch.setattr(magics.context, "project", "project-from-context")
+    monkeypatch.setattr(
+        magics.context.default_query_job_config, "use_query_cache", False
+    )
+
+    ip.run_cell_magic("bigquery", "", QUERY_STRING)
+
+    conn.api_request.assert_called_with(
+        method="POST",
+        path="/projects/project-from-context/jobs",
+        data=mock.ANY,
+        timeout=DEFAULT_TIMEOUT,
+    )
+    jobs_insert_call = [
+        call
+        for call in conn.api_request.call_args_list
+        if call[1]["path"] == "/projects/project-from-context/jobs"
+    ][0]
+    assert not jobs_insert_call[1]["data"]["configuration"]["query"]["useQueryCache"]
+
+
 @pytest.mark.usefixtures("ipython_interactive")
 @pytest.mark.skipif(pandas is None, reason="Requires `pandas`")
 def test_bigquery_magic_w_progress_bar_type_w_context_setter(monkeypatch):
